@@ -63,19 +63,19 @@ class Freebox(IPlugin):
 					# séparation de rs['idx'], nombre   len(maliste)
 	# ###   140826			i = 1
 	# ###   140826			while i <= int(rs['idx_sec']):
-#
-# 
-					for i in range int(rs['idx_sec']):
-		#				if rs['idx'][i - rang] == '|':
-						rangs.append(rang)
-						log.msg(" rang  :  %s" % (rangs)
+	#
+	# 
+	##1				for i in range int(rs['idx_sec']):
+	#					if rs['idx'][i - rang] == '|':
+	##1					rangs.append(rang)
+	##1					log.msg(" rang  :  %s" % (rangs)
 #>>> for rang in range(len(mot)):  # La variable rang parcourt les entiers de 0 au rang de la dernière lettre du mot.
 #...     if mot[rang] == 'i':
 #...         rangs.append(rang)    # Si la lettre du mot est 'i', on stocke le rang dans notre liste.
 #>>> rangs                         # On affiche le résultat.
 #[5, 7]
-					# search position '|' dans rs['idx']	
-					# 'http://hd2.freebox.fr/pub/remote_control?code=35782633&key=%s' % (rs))
+						# search position '|' dans rs['idx']	
+						# 'http://hd2.freebox.fr/pub/remote_control?code=35782633&key=%s' % (rs))
 					for rx in range int(rs['idx_sec']):
 						log.msg(" rx  :  %s" % (rx)
 						log.msg("idx_sec  :  %s" % (int(rs['idx_sec'])))
